Stan Math Library: stan/math/prim/mat/fun/columns_dot_self.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

columns_dot_self.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_COLUMNS_DOT_SELF_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_COLUMNS_DOT_SELF_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5
6 namespace stan {
7 namespace math {
8
14 template<typename T, int R, int C>
15 inline Eigen::Matrix<T, 1, C>
16 columns_dot_self(const Eigen::Matrix<T, R, C>& x) {
17 return x.colwise().squaredNorm();
18 }
19
20 }
21 }
22 #endif
stan
Definition: log_sum_exp.hpp:8
Eigen.hpp
stan::math::columns_dot_self
Eigen::Matrix< fvar< T >, 1, C > columns_dot_self(const Eigen::Matrix< fvar< T >, R, C > &x)
Definition: columns_dot_self.hpp:15

[ Stan Home Page ] © 2011–2016, Stan Development Team.